@@ -1,3 +1,6 @@
+# the code below was mostly contributed by @egnha from
+# https://github.com/yihui/formatR/pull/66
+
 deparse_collapse = function(x) {
   d = deparse(x)
   if (length(d) > 1L) {
@@ -65,7 +68,7 @@ overflow_message = function(overflow, width, indent, text) {
               collapse = '')
     sprintf('(%s) \"%s\"', nchar(l), l)
   }, character(1L))
-  paste(c(header, args), collapse = '\n')
+  one_string(c(header, args))
 }
 
 tidy_usage = function(nm, usg, width, indent, fail) {
@@ -92,28 +95,27 @@ tidy_usage = function(nm, usg, width, indent, fail) {
 #' Show the usage of a function
 #'
 #' Print the reformatted usage of a function. The arguments of the function are
-#' searched by \code{\link{argsAnywhere}}, so the function can be either
-#' exported or non-exported in a package. S3 methods will be marked.
-#'
-#' @param FUN the function name
-#' @param width the width of output
-#' @param tidy whether to reformat the usage code
-#' @param output whether to write the output to the console (via
-#'   \code{\link{cat}})
-#' @param indent.by.FUN whether to indent subsequent lines by the width of the
-#'   function name (see \dQuote{Details})
-#' @param fail a character string that determines whether to generate a warning,
-#'   stop, or do neither, if the width constraint is unfulfillable (default is
-#'   \code{"warn"})
-#' @return The R code for the usage is returned as a character string
-#'   (invisibly).
+#' searched by \code{\link{argsAnywhere}()}, so the function can be either
+#' exported or non-exported from a package. S3 methods will be marked.
+#' @param FUN The function name.
+#' @param width The width of the output.
+#' @param tidy Whether to reformat the usage code.
+#' @param output Whether to print the output to the console (via
+#'   \code{\link{cat}()}).
+#' @param indent.by.FUN Whether to indent subsequent lines by the width of the
+#'   function name (see \dQuote{Details}).
+#' @param fail A character string that represents the action taken when the
+#'   width constraint is unfulfillable. "warn" and "stop" will signal warnings
+#'   and errors, while "none" will do nothing.
+#' @return Reformatted usage code of a function, in character strings
+#'   (invisible).
 #' @details Line breaks in the output occur between arguments. In particular,
 #'   default values of arguments will not be split across lines.
 #'
 #'   When \code{indent.by.FUN} is \code{FALSE}, indentation is set by the option
 #'   \code{\link{getOption}("formatR.indent", 4L)}, the default value of the
-#'   \code{indent} argument of \code{\link{tidy_source}}.
-#' @seealso \code{\link{tidy_source}}
+#'   \code{indent} argument of \code{\link{tidy_source}()}.
+#' @seealso \code{\link{tidy_source}()}
 #' @export
 #' @examples library(formatR)
 #' usage(var)
